ProSHADE: Member List

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

ProSHADE_internal_data::ProSHADE_data Member List

This is the complete list of members for ProSHADE_internal_data::ProSHADE_data, including all inherited members.

aAngle | ProSHADE_internal_data::ProSHADE_data |
addExtraSpace(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
allocateEMatrices(ProSHADE_settings *settings, proshade_unsign band) | ProSHADE_internal_data::ProSHADE_data |
allocateRotatedSHMemory(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
allocateRRPMemory(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data | protected
allocateSO3CoeffsSpace(proshade_unsign band) | ProSHADE_internal_data::ProSHADE_data |
allocateWignerMatricesSpace(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
bAngle | ProSHADE_internal_data::ProSHADE_data |
cAngle | ProSHADE_internal_data::ProSHADE_data |
centreMapOnCOM(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
computeGroupElementsForGroup(std::vector< std::vector< proshade_double > > *allCSyms, proshade_unsign grPosition) | ProSHADE_internal_data::ProSHADE_data |
computeGroupElementsForGroup(std::vector< proshade_double * > *allCSyms, proshade_unsign grPosition) | ProSHADE_internal_data::ProSHADE_data |
computeOptimalTranslation(proshade_double eulA, proshade_double eulB, proshade_double eulG, proshade_double trsX, proshade_double trsY, proshade_double trsZ) | ProSHADE_internal_data::ProSHADE_data |
computePdbRotationCentre(void) | ProSHADE_internal_data::ProSHADE_data |
computeRotatedSH(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
computeRotationFunction(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
computeRRPMatrices(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
computeSphericalHarmonics(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
computeTranslationMap(ProSHADE_internal_data::ProSHADE_data *obj1) | ProSHADE_internal_data::ProSHADE_data |
convertRotationFunction(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
createNewMapFromBounds(ProSHADE_settings *settings, ProSHADE_data *&newStr, proshade_signed *newBounds) | ProSHADE_internal_data::ProSHADE_data |
deepCopyMap(proshade_double *&saveTo, proshade_unsign verbose) | ProSHADE_internal_data::ProSHADE_data |
detectSymmetryFromAngleAxisSpace(ProSHADE_settings *settings, std::vector< proshade_double * > *axes, std::vector< std::vector< proshade_double > > *allCs) | ProSHADE_internal_data::ProSHADE_data |
detectSymmetryInStructure(ProSHADE_settings *settings, std::vector< proshade_double * > *axes, std::vector< std::vector< proshade_double > > *allCs) | ProSHADE_internal_data::ProSHADE_data |
detectSymmetryInStructurePython(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
eMatrices | ProSHADE_internal_data::ProSHADE_data |
figureIndexStartStop(void) | ProSHADE_internal_data::ProSHADE_data | protected
fileName | ProSHADE_internal_data::ProSHADE_data |
fileType | ProSHADE_internal_data::ProSHADE_data |
findBestCScore(std::vector< proshade_double * > *CSym, proshade_unsign *symInd) | ProSHADE_internal_data::ProSHADE_data |
findBestDScore(std::vector< proshade_double * > *DSym, proshade_unsign *symInd) | ProSHADE_internal_data::ProSHADE_data |
findIScore(std::vector< proshade_double * > *ISym) | ProSHADE_internal_data::ProSHADE_data |
findMapCOM(void) | ProSHADE_internal_data::ProSHADE_data |
findOScore(std::vector< proshade_double * > *OSym) | ProSHADE_internal_data::ProSHADE_data |
findRequestedCSymmetryFromAngleAxis(ProSHADE_settings *settings, proshade_unsign fold, proshade_double *peakThres) | ProSHADE_internal_data::ProSHADE_data |
findTScore(std::vector< proshade_double * > *TSym) | ProSHADE_internal_data::ProSHADE_data |
getAllGroupElements(ProSHADE_settings *settings, std::vector< proshade_unsign > axesList, std::string groupType="", proshade_double matrixTolerance=0.05) | ProSHADE_internal_data::ProSHADE_data |
getAnySphereRadius(proshade_unsign shell) | ProSHADE_internal_data::ProSHADE_data |
getBestRotationMapPeaksEulerAngles(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
getBestTranslationMapPeaksAngstrom(ProSHADE_internal_data::ProSHADE_data *staticStructure, proshade_double eulA, proshade_double eulB, proshade_double eulG) | ProSHADE_internal_data::ProSHADE_data |
getComparisonBand(void) | ProSHADE_internal_data::ProSHADE_data |
getCyclicSymmetriesList(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
getCyclicSymmetriesListFromAngleAxis(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
getDihedralSymmetriesList(ProSHADE_settings *settings, std::vector< proshade_double * > *CSymList) | ProSHADE_internal_data::ProSHADE_data |
getEMatrixByBand(proshade_unsign band) | ProSHADE_internal_data::ProSHADE_data |
getEMatrixValue(proshade_unsign band, proshade_unsign order1, proshade_unsign order2, proshade_double *valueReal, proshade_double *valueImag) | ProSHADE_internal_data::ProSHADE_data |
getIcosahedralSymmetriesList(ProSHADE_settings *settings, std::vector< proshade_double * > *CSymList) | ProSHADE_internal_data::ProSHADE_data |
getImagEMatrixValuesForLM(proshade_signed band, proshade_signed order1, double *eMatsLMImag, int len) | ProSHADE_internal_data::ProSHADE_data |
getImagRotFunction(double *rotFunImag, int len) | ProSHADE_internal_data::ProSHADE_data |
getImagSO3Coeffs(double *so3CoefsImag, int len) | ProSHADE_internal_data::ProSHADE_data |
getImagSphHarmValue(proshade_unsign band, proshade_unsign order, proshade_unsign shell) | ProSHADE_internal_data::ProSHADE_data |
getImagTranslationFunction(double *trsFunImag, int len) | ProSHADE_internal_data::ProSHADE_data |
getIntegrationWeight(void) | ProSHADE_internal_data::ProSHADE_data |
getInternalMap(void) | ProSHADE_internal_data::ProSHADE_data |
getInvSO3Coeffs(void) | ProSHADE_internal_data::ProSHADE_data |
getMapValue(proshade_unsign pos) | ProSHADE_internal_data::ProSHADE_data |
getMaxBand(void) | ProSHADE_internal_data::ProSHADE_data |
getMaxSpheres(void) | ProSHADE_internal_data::ProSHADE_data |
getNoRecommendedSymmetryAxes(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
getOctahedralSymmetriesList(ProSHADE_settings *settings, std::vector< proshade_double * > *CSymList) | ProSHADE_internal_data::ProSHADE_data |
getOverlayRotationFunction(ProSHADE_settings *settings, ProSHADE_internal_data::ProSHADE_data *obj2) | ProSHADE_internal_data::ProSHADE_data |
getPredictedIcosahedralSymmetriesList(ProSHADE_settings *settings, std::vector< proshade_double * > *CSymList, proshade_double matrixTolerance) | ProSHADE_internal_data::ProSHADE_data |
getPredictedOctahedralSymmetriesList(ProSHADE_settings *settings, std::vector< proshade_double * > *CSymList, proshade_double matrixTolerance) | ProSHADE_internal_data::ProSHADE_data |
getRealEMatrixValuesForLM(proshade_signed band, proshade_signed order1, double *eMatsLMReal, int len) | ProSHADE_internal_data::ProSHADE_data |
getRealRotFunction(double *rotFunReal, int len) | ProSHADE_internal_data::ProSHADE_data |
getRealSO3Coeffs(double *so3CoefsReal, int len) | ProSHADE_internal_data::ProSHADE_data |
getRealSphHarmValue(proshade_unsign band, proshade_unsign order, proshade_unsign shell) | ProSHADE_internal_data::ProSHADE_data |
getRealTranslationFunction(double *trsFunReal, int len) | ProSHADE_internal_data::ProSHADE_data |
getReBoxBoundaries(ProSHADE_settings *settings, proshade_signed *&ret) | ProSHADE_internal_data::ProSHADE_data |
getRecommendedSymmetryFold(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
getRecommendedSymmetryType(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
getRotMatrixFromRotFunInds(proshade_signed aI, proshade_signed bI, proshade_signed gI, double *rotMat, int len) | ProSHADE_internal_data::ProSHADE_data |
getRRPValue(proshade_unsign band, proshade_unsign sh1, proshade_unsign sh2) | ProSHADE_internal_data::ProSHADE_data |
getShellBandwidth(proshade_unsign shell) | ProSHADE_internal_data::ProSHADE_data |
getSO3Coeffs(void) | ProSHADE_internal_data::ProSHADE_data |
getSpherePositions(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
getSpherePosValue(proshade_unsign shell) | ProSHADE_internal_data::ProSHADE_data |
getSymmetryAxis(ProSHADE_settings *settings, proshade_unsign axisNo) | ProSHADE_internal_data::ProSHADE_data |
getTetrahedralSymmetriesList(ProSHADE_settings *settings, std::vector< proshade_double * > *CSymList) | ProSHADE_internal_data::ProSHADE_data |
getTranslationFnPointer(void) | ProSHADE_internal_data::ProSHADE_data |
getWignerMatrixValue(proshade_unsign band, proshade_unsign order1, proshade_unsign order2, proshade_double *valueReal, proshade_double *valueImag) | ProSHADE_internal_data::ProSHADE_data |
getXAxisOrigin(void) | ProSHADE_internal_data::ProSHADE_data |
getXDim(void) | ProSHADE_internal_data::ProSHADE_data |
getXDimSize(void) | ProSHADE_internal_data::ProSHADE_data |
getXFromPtr(void) | ProSHADE_internal_data::ProSHADE_data |
getXToPtr(void) | ProSHADE_internal_data::ProSHADE_data |
getYAxisOrigin(void) | ProSHADE_internal_data::ProSHADE_data |
getYDim(void) | ProSHADE_internal_data::ProSHADE_data |
getYDimSize(void) | ProSHADE_internal_data::ProSHADE_data |
getYFromPtr(void) | ProSHADE_internal_data::ProSHADE_data |
getYToPtr(void) | ProSHADE_internal_data::ProSHADE_data |
getZAxisOrigin(void) | ProSHADE_internal_data::ProSHADE_data |
getZDim(void) | ProSHADE_internal_data::ProSHADE_data |
getZDimSize(void) | ProSHADE_internal_data::ProSHADE_data |
getZFromPtr(void) | ProSHADE_internal_data::ProSHADE_data |
getZToPtr(void) | ProSHADE_internal_data::ProSHADE_data |
inputOrder | ProSHADE_internal_data::ProSHADE_data |
integrationWeight | ProSHADE_internal_data::ProSHADE_data |
internalMap | ProSHADE_internal_data::ProSHADE_data |
interpolateMapFromSpheres(ProSHADE_settings *settings, proshade_double *&densityMapRotated) | ProSHADE_internal_data::ProSHADE_data |
invertMirrorMap(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
invertSHCoefficients(void) | ProSHADE_internal_data::ProSHADE_data |
isEmpty | ProSHADE_internal_data::ProSHADE_data |
mapCOMProcessChangeX | ProSHADE_internal_data::ProSHADE_data |
mapCOMProcessChangeY | ProSHADE_internal_data::ProSHADE_data |
mapCOMProcessChangeZ | ProSHADE_internal_data::ProSHADE_data |
mapMovFromsChangeX | ProSHADE_internal_data::ProSHADE_data |
mapMovFromsChangeY | ProSHADE_internal_data::ProSHADE_data |
mapMovFromsChangeZ | ProSHADE_internal_data::ProSHADE_data |
mapToSpheres(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
maskMap(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
maxCompBand | ProSHADE_internal_data::ProSHADE_data |
maxShellBand | ProSHADE_internal_data::ProSHADE_data |
normaliseEMatrixValue(proshade_unsign band, proshade_unsign order1, proshade_unsign order2, proshade_double normF) | ProSHADE_internal_data::ProSHADE_data |
normaliseMap(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
noSpheres | ProSHADE_internal_data::ProSHADE_data |
optimiseDihedralAngleFromAngleAxis(ProSHADE_settings *settings, proshade_double angle, proshade_double *axis1, proshade_double *axis2) | ProSHADE_internal_data::ProSHADE_data |
originalMapXCom | ProSHADE_internal_data::ProSHADE_data |
originalMapYCom | ProSHADE_internal_data::ProSHADE_data |
originalMapZCom | ProSHADE_internal_data::ProSHADE_data |
originalPdbRotCenX | ProSHADE_internal_data::ProSHADE_data |
originalPdbRotCenY | ProSHADE_internal_data::ProSHADE_data |
originalPdbRotCenZ | ProSHADE_internal_data::ProSHADE_data |
originalPdbTransX | ProSHADE_internal_data::ProSHADE_data |
originalPdbTransY | ProSHADE_internal_data::ProSHADE_data |
originalPdbTransZ | ProSHADE_internal_data::ProSHADE_data |
processInternalMap(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
ProSHADE_data(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
ProSHADE_data(ProSHADE_settings *settings, std::string strName, double *mapVals, int len, proshade_single xDmSz, proshade_single yDmSz, proshade_single zDmSz, proshade_unsign xDmInd, proshade_unsign yDmInd, proshade_unsign zDmInd, proshade_signed xFr, proshade_signed yFr, proshade_signed zFr, proshade_signed xT, proshade_signed yT, proshade_signed zT, proshade_unsign inputO) | ProSHADE_internal_data::ProSHADE_data |
readInMAP(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data | protected
readInPDB(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data | protected
readInStructure(std::string fName, proshade_unsign inputO, ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
removePhaseInormation(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
reportOverlayResults(ProSHADE_settings *settings, std::vector< proshade_double > *rotationCentre, std::vector< proshade_double > *eulerAngles, std::vector< proshade_double > *finalTranslation) | ProSHADE_internal_data::ProSHADE_data |
reportSymmetryResults(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
reSampleMap(ProSHADE_settings *settings) | ProSHADE_internal_data::ProSHADE_data |
rotateMap(ProSHADE_settings *settings, proshade_double eulerAlpha, proshade_double eulerBeta, proshade_double eulerGamma) | ProSHADE_internal_data::ProSHADE_data |
rotSphericalHarmonics | ProSHADE_internal_data::ProSHADE_data |
rrpMatrices | ProSHADE_internal_data::ProSHADE_data |
saveDetectedSymmetries(ProSHADE_settings *settings, std::vector< proshade_double * > *CSyms, std::vector< std::vector< proshade_double > > *allCs) | ProSHADE_internal_data::ProSHADE_data |
saveRecommendedSymmetry(ProSHADE_settings *settings, std::vector< proshade_double * > *CSym, std::vector< proshade_double * > *DSym, std::vector< proshade_double * > *TSym, std::vector< proshade_double * > *OSym, std::vector< proshade_double * > *ISym, std::vector< proshade_double * > *axes) | ProSHADE_internal_data::ProSHADE_data |
saveRequestedSymmetryC(ProSHADE_settings *settings, std::vector< proshade_double * > *CSym, std::vector< proshade_double * > *axes) | ProSHADE_internal_data::ProSHADE_data |
saveRequestedSymmetryD(ProSHADE_settings *settings, std::vector< proshade_double * > *DSym, std::vector< proshade_double * > *axes) | ProSHADE_internal_data::ProSHADE_data |
setEMatrixValue(proshade_unsign band, proshade_unsign order1, proshade_unsign order2, proshade_complex val) | ProSHADE_internal_data::ProSHADE_data |
setIntegrationWeight(proshade_double intW) | ProSHADE_internal_data::ProSHADE_data |
setIntegrationWeightCumul(proshade_double intW) | ProSHADE_internal_data::ProSHADE_data |
setPDBMapValues(void) | ProSHADE_internal_data::ProSHADE_data | protected
setSO3CoeffValue(proshade_unsign position, proshade_complex val) | ProSHADE_internal_data::ProSHADE_data |
setWignerMatrixValue(proshade_complex val, proshade_unsign band, proshade_unsign order1, proshade_unsign order2) | ProSHADE_internal_data::ProSHADE_data |
shellBandExists(proshade_unsign shell, proshade_unsign bandVal) | ProSHADE_internal_data::ProSHADE_data |
so3Coeffs | ProSHADE_internal_data::ProSHADE_data |
so3CoeffsArrayIndex(proshade_signed order1, proshade_signed order2, proshade_signed band) | ProSHADE_internal_data::ProSHADE_data |
so3CoeffsInverse | ProSHADE_internal_data::ProSHADE_data |
sphereMappedRotFun (defined in ProSHADE_internal_data::ProSHADE_data) | ProSHADE_internal_data::ProSHADE_data |
spherePos | ProSHADE_internal_data::ProSHADE_data |
spheres | ProSHADE_internal_data::ProSHADE_data |
sphericalHarmonics | ProSHADE_internal_data::ProSHADE_data |
translateMap(ProSHADE_settings *settings, proshade_double trsX, proshade_double trsY, proshade_double trsZ) | ProSHADE_internal_data::ProSHADE_data |
translationMap | ProSHADE_internal_data::ProSHADE_data |
wignerMatrices | ProSHADE_internal_data::ProSHADE_data |
writeMap(std::string fName, std::string title="Created by ProSHADE and written by GEMMI", int mode=2) | ProSHADE_internal_data::ProSHADE_data |
writeMask(std::string fName, proshade_double *mask) | ProSHADE_internal_data::ProSHADE_data |
writeOutOverlayFiles(ProSHADE_settings *settings, proshade_double eulA, proshade_double eulB, proshade_double eulG, std::vector< proshade_double > *rotCentre, std::vector< proshade_double > *ultimateTranslation) | ProSHADE_internal_data::ProSHADE_data |
writePdb(std::string fName, proshade_double euA=0.0, proshade_double euB=0.0, proshade_double euG=0.0, proshade_double trsX=0.0, proshade_double trsY=0.0, proshade_double trsZ=0.0, bool firstModel=true) | ProSHADE_internal_data::ProSHADE_data |
xAxisOrder | ProSHADE_internal_data::ProSHADE_data |
xAxisOrigin | ProSHADE_internal_data::ProSHADE_data |
xAxisOriginOriginal | ProSHADE_internal_data::ProSHADE_data |
xCom | ProSHADE_internal_data::ProSHADE_data |
xDimIndices | ProSHADE_internal_data::ProSHADE_data |
xDimIndicesOriginal | ProSHADE_internal_data::ProSHADE_data |
xDimSize | ProSHADE_internal_data::ProSHADE_data |
xDimSizeOriginal | ProSHADE_internal_data::ProSHADE_data |
xFrom | ProSHADE_internal_data::ProSHADE_data |
xGridIndices | ProSHADE_internal_data::ProSHADE_data |
xTo | ProSHADE_internal_data::ProSHADE_data |
yAxisOrder | ProSHADE_internal_data::ProSHADE_data |
yAxisOrigin | ProSHADE_internal_data::ProSHADE_data |
yAxisOriginOriginal | ProSHADE_internal_data::ProSHADE_data |
yCom | ProSHADE_internal_data::ProSHADE_data |
yDimIndices | ProSHADE_internal_data::ProSHADE_data |
yDimIndicesOriginal | ProSHADE_internal_data::ProSHADE_data |
yDimSize | ProSHADE_internal_data::ProSHADE_data |
yDimSizeOriginal | ProSHADE_internal_data::ProSHADE_data |
yFrom | ProSHADE_internal_data::ProSHADE_data |
yGridIndices | ProSHADE_internal_data::ProSHADE_data |
yTo | ProSHADE_internal_data::ProSHADE_data |
zAxisOrder | ProSHADE_internal_data::ProSHADE_data |
zAxisOrigin | ProSHADE_internal_data::ProSHADE_data |
zAxisOriginOriginal | ProSHADE_internal_data::ProSHADE_data |
zCom | ProSHADE_internal_data::ProSHADE_data |
zDimIndices | ProSHADE_internal_data::ProSHADE_data |
zDimIndicesOriginal | ProSHADE_internal_data::ProSHADE_data |
zDimSize | ProSHADE_internal_data::ProSHADE_data |
zDimSizeOriginal | ProSHADE_internal_data::ProSHADE_data |
zeroPaddToDims(proshade_unsign xDim, proshade_unsign yDim, proshade_unsign zDim) | ProSHADE_internal_data::ProSHADE_data |
zFrom | ProSHADE_internal_data::ProSHADE_data |
zGridIndices | ProSHADE_internal_data::ProSHADE_data |
zTo | ProSHADE_internal_data::ProSHADE_data |
~ProSHADE_data(void) | ProSHADE_internal_data::ProSHADE_data |